Learn R Programming

ontologySimilarity (version 2.3)

GO_IC: Gene Ontology terms information content.

Description

Numeric vector containing the information content of Gene Ontology terms based on frequencies of annotation data object gene_GO_terms. The object can be derived using the function get_term_info_content and data object go from the ontologyIndex package.

Arguments

Format

List of character vectors.