powered by
Create a numeric matrix of similarities between two lists of term sets, but only averaging over the terms in sets from A the similarities of the best matches in sets from B.
A
B
get_asym_sim_grid(A, B, ...)
Numeric matrix of similarities
List of term sets.
Other arguments to be passed to get_sim_grid.
get_sim_grid
get_sim_grid get_profile_sims
get_profile_sims