Learn R Programming

ontologySimilarity (version 1.0)

get_sim_grid: Get similarity matrix from a term-to-term similarity matrix between two sets of term sets

Description

Equivalent to get_sim_mat for two sets of term sets.

Usage

get_sim_grid(term_sim_mat, term_sets, term_sets2 = term_sets, combine = c("average", "product"))

Arguments

term_sim_mat
Numeric matrix with rows and columns corresponding to (and named by) term IDs, and cells containing the similarity between the row and column term
term_sets
List of character vectors of ontological term IDs.
term_sets2
Second set of term sets
combine
Character string - either average or product, indicating whether to use the `best-match-average' or `best-match-product' method

Value

Numeric matrix of between-term set similarities