p-value of group similarity, calculated by estimating the proportion by random sampling of groups the same size as group which have at least as great group similarity than does group.
get_sim_p(pop_sim, ...)# S3 method for integer
get_sim_p(pop_sim, ...)
# S3 method for numeric
get_sim_p(pop_sim, group, ...)
# S3 method for matrix
get_sim_p(pop_sim, group, ...)
# S3 method for sim_index
get_sim_p(pop_sim, group, ...)
# S3 method for default
get_sim_p(pop_sim, group, type, min_its = 1000,
max_its = 1e+05, signif = 0.05, log_dismiss = log(1e-06),
group_sim = "average", ...)
An object representing the similarities of an indexed population of objects.
Arguments for get_sim_p.
Character or integer vector specifying names/indices of subgroup for which to calculate a group similarity p-value.
Either "matrix", "sim_index" or "numeric" - the type of the pop_sim object.
Minimum number of simulated group similarities to calculate
Maximum number of simulated group similarities to calculate
Threshold p-value of statistical significance
Threshold of log probability, below which to trigger return of current estimated p-value
String Either "average" or "min", determining how to calculate the similarity of a group of term sets over all pairwise combinations of group members
p-value.