Get similarity p-value for subgroup of list of term sets
get_sim_p_from_ontology(ontology, term_sets,
information_content = descendants_IC(ontology),
term_sim_method = "lin", combine = "average", ...)ontology_index object.
List of character vectors of ontological term IDs.
Numeric vector of information contents of terms (named by term)
Character string equalling either "lin" or "resnik" to use Lin or Resnik's expression for the similarity of terms.
Character string - either "average" or "product", indicating whether to use the best-match-product' method, or function accepting two arguments - the first, the similarity matrix obtained by averaging across term sets in term_sets, and the second averaging across those in term_sets2.
Other arguments to be passed to get_sim_p.
Numeric value.