Learn R Programming

ontologySimilarity (version 1.0)

get_sim_to_profile_p: Get p-value for best-match-average similarity between two term sets

Description

Get p-value by comparison of similarity of profile and term_set to distribution of similarities obtained by simulating random term sets (i.e. comprising random sets of terms the same size as term_set) and calculating the similarity to profile.

Usage

get_sim_to_profile_p(term_sim_mat, profile, term_set, sample_from = colnames(term_sim_mat), min_its = 1000, max_its = 1e+05, signif = 0.05, log_dismiss = -10)

Arguments

term_sim_mat
Numeric matrix with rows and columns corresponding to (and named by) term IDs, and cells containing the similarity between the row and column term
profile
Character vector of ontological term IDs
term_set
Character vector of ontological term IDs
sample_from
Character vector of ontological term IDs to sample term sets from
min_its
Minimum number of simulated group similarities to calculate
max_its
Maximum number of simulated group similarities to calculate
signif
Threshold p-value of statistical significance
log_dismiss
Threshold of log probability, below which to trigger return of current estimated p-value

Value

Numeric p-value