Learn R Programming

ontologySimilarity (version 1.0)

get_term_set_to_term_sims: Get `term sets to term' similarity matrix

Description

Using a matrix of between-term similarities (e.g. the kind obtained from applying the function get_term_sim_mat), create a numeric matrix of `term set-to-term' similarities using either the `best-match' approach (i.e. the similarity of the term will be the maximum term-to-term similarity in term_sim_mat amongst the term set terms).

Usage

get_term_set_to_term_sims(term_sim_mat, term_sets)

Arguments

term_sim_mat
Numeric matrix with rows and columns corresponding to (and named by) term IDs, and cells containing the similarity between the row and column term
term_sets
List of character vectors of ontological term IDs.

Value

Numeric matrix of term set-to-term similarities