Learn R Programming

ontologySimilarity (version 1.0)

ontologySimilarity-package: Functions for Calculating Ontological Similarities

Description

Functions for calculating semantic similarities between ontological terms or sets of ontological terms based on term information content and assessing statistical significance of similarity in the context of a collection of phenotypes.

Arguments

Details

Package:
ontologySimilarity
Type:
Package
Version:
1.0
Date:
2016-01-12
License:
GPL (>= 2)
Functions for calculating ontological similarity. Important functions include

References

`The Human Phenotype Ontology project: linking molecular biology and disease through phenotype data', Nucl. Acids Res. (1 January 2014) 42 (D1): D966-D974 doi:10.1093/nar/gkt1026