get_asym_sim_grid: Get asymmetrical similarity matrix
Description
Create a numeric matrix of similarities between two lists of term sets, but only averaging over the terms in sets from A the similarities of the best matches in sets from B.
Usage
get_asym_sim_grid(A, B, ...)
Value
Numeric matrix of similarities