Given a lower triangular similarity matrix, construct a distance matrix where the rows are the ranks of the column cases with respect to similarity to the row case. If relative similarity is of interest, this rank-transformation may reduce bias in favour of high similarity scores in downstream analysis.
get_similarity_rank_matrix(similarity_matrix, symmetric = TRUE)Matrix of rank similarities.
Lower triangular numeric matrix of similarities, where the rownames and colnames are identical to the case IDs.
Logical value determining whether to `symmetrify' resultant matrix by averaging rank similarity of A -> B and B -> A.