get_similarity_rank_matrix: Get matrix of similarity rank from similarity matrix
Description
Given a lower triangular similarity matrix, construct a distance matrix where the rows are the ranks of the column cases, ranked by similarity to the row case
Usage
get_similarity_rank_matrix(similarity_matrix)
Arguments
similarity_matrix
Lower triangular numeric matrix of similarities, where the rownames and colnames are identical to the case IDs